/* FichothequeLib_Tools - Copyright (c) 2020-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.duplication;

import net.fichotheque.Fichotheque;
import net.fichotheque.Subset;
import net.fichotheque.SubsetItem;
import net.fichotheque.croisement.CroisementEditor;
import net.fichotheque.croisement.Croisements;
import net.fichotheque.croisement.Lien;
import net.fichotheque.eligibility.SubsetEligibility;
import net.fichotheque.tools.FichothequeTools;
import net.fichotheque.tools.croisement.CroisementChangeEngine;


/**
 *
 * @author Vincent Calame
 */
public final class DuplicationUtils {

    private DuplicationUtils() {

    }

    public static void copyCroisements(CroisementEditor croisementEditor, SubsetMatch subsetMatch, SubsetEligibility subsetEligibility) {
        for (SubsetMatch.Entry entry : subsetMatch.getEntryList()) {
            FichothequeTools.copyCroisements(croisementEditor, entry.getOrigin(), entry.getDestination(), subsetEligibility);
        }
    }

    public static void linkToOrigin(CroisementEditor croisementEditor, SubsetMatch subsetMatch, String mode, int poids) {
        for (SubsetMatch.Entry entry : subsetMatch.getEntryList()) {
            SubsetItem destination = entry.getDestination();
            CroisementChangeEngine cce = CroisementChangeEngine.appendOrPoidsReplaceEngine(destination);
            cce.addLien(entry.getOrigin(), mode, poids);
            croisementEditor.updateCroisements(destination, cce.toCroisementChanges());

        }
    }

    public static void replicateLinks(CroisementEditor croisementEditor, SubsetMatch subsetMatch) {
        Subset originSubset = subsetMatch.getOriginSubset();
        Fichotheque fichotheque = originSubset.getFichotheque();
        for (SubsetMatch.Entry entry : subsetMatch.getEntryList()) {
            SubsetItem origin = entry.getOrigin();
            Croisements croisements = fichotheque.getCroisements(origin, originSubset);
            if (!croisements.isEmpty()) {
                SubsetItem destination = entry.getDestination();
                CroisementChangeEngine initialCroisementChangeEngine = CroisementChangeEngine.appendOrPoidsReplaceEngine(destination);
                for (Croisements.Entry croisementEntry : croisements.getEntryList()) {
                    SubsetItem other = croisementEntry.getSubsetItem();
                    if (other.getId() > origin.getId()) {
                        SubsetMatch.Entry otherEntry = subsetMatch.getEntryByOrigin(other.getId());
                        if (otherEntry != null) {
                            for (Lien lien : croisementEntry.getCroisement().getLienList()) {
                                initialCroisementChangeEngine.addLien(otherEntry.getDestination(), lien.getMode(), lien.getPoids());
                            }
                        }
                    }
                }
                croisementEditor.updateCroisements(destination, initialCroisementChangeEngine.toCroisementChanges());
            }
        }
    }

}
